import _AttachMixin = require("./_AttachMixin");
import { _WidgetBaseConstructor } from "./_WidgetBase";

interface _TemplatedMixin extends _AttachMixin {

    /**
     * A string that represents the widget template.
     * Use in conjunction with dojo.cache() to load from a file.
     */
    templateString: string;

    /**
     * Path to template (HTML file) for this widget relative to dojo.baseUrl.
     * Deprecated: use templateString with require([... "dojo/text!..."], ...) instead
     */
    templatePath: string;

    /**
     * Set _AttachMixin.searchContainerNode to true for back-compat for widgets that have data-dojo-attach-point's
     * and events inside this.containerNode.   Remove for 2.0.
     */
    searchContainerNode: boolean;

    /**
     * Construct the UI for this widget from a template, setting this.domNode.
     */
    buildRendering(): void;
}

interface _TemplatedMixinConstructor extends _WidgetBaseConstructor<_TemplatedMixin> {
    /**
     * Static method to get a template based on the templatePath or
     * templateString key
     */
    getCachedTemplate(templateString: string, alwaysUseString: string, doc?: Document): string | HTMLElement;
}

declare module "dojo/_base/kernel" {
    interface Dijit {
        _TemplatedMixin: _TemplatedMixinConstructor;
    }
}

declare const _TemplatedMixin: _TemplatedMixinConstructor;
export = _TemplatedMixin;
